/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.calcengine.osgi;

import org.apache.commons.lang.StringUtils;

import com.openexchange.config.ConfigurationService;
import com.openexchange.office.calcengine.client.CalcEngineClientFactory;
import com.openexchange.office.calcengine.client.CalcEngineDescriptor;
import com.openexchange.office.calcengine.client.ECalcEngineMode;
import com.openexchange.office.calcengine.client.ICalcEngineClient;
import com.openexchange.osgi.HousekeepingActivator;

//-------------------
//- class Activator -
//-------------------

/**
 * {@link HousekeepingActivator}
 */
public class CalcEngineServerActivator extends HousekeepingActivator
{
    // -----------------------------------------------------------------------------------
    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(CalcEngineServerActivator.class));

    // -----------------------------------------------------------------------------------
    private static final String LOGPREFIX = "Calc Engine Env : com.openexchange.office.calcengine : ";
    
    // -----------------------------------------------------------------------------------
    private static final Class< ? >[] SERVICELIST = new Class< ? >[] {ConfigurationService.class};
    
    // -----------------------------------------------------------------------------------
    public CalcEngineServerActivator ()
    {
    	super ();
    }

    // -----------------------------------------------------------------------------------
    @Override
    protected Class<?>[] getNeededServices()
    {
        return SERVICELIST;
    }

    // -----------------------------------------------------------------------------------
    @Override
    protected void startBundle()
    	throws Exception
    {
        try
        {
            // register factory for instances of type ICalcEngineClient

            logINFO("start environment ...");                        
            final CalcEngineClientFactory aCalcEngineClientFactory = new CalcEngineClientFactory(this);
            registerService(CalcEngineClientFactory.class, aCalcEngineClientFactory);
            logINFO("OK");
        }
        catch (Throwable ex)
        {
            logERROR (ex);
            throw new RuntimeException(ex);
        }
    }
    
    // -----------------------------------------------------------------------------------
    @Override
    public void stopBundle()
    	throws Exception
    {
        logINFO("stop environment ...");                        
        logINFO("OK");                        
    }

    // -----------------------------------------------------------------------------------
    private static final void logINFO (final String sMessage)
    {
    	LOG.info(LOGPREFIX+sMessage+"\n");
    }

    // -----------------------------------------------------------------------------------
    private static final void logERROR (final Throwable aError)
    {
    	LOG.error(LOGPREFIX+aError.getMessage()+"\n", aError);
    }
}
